@@ -4,9 +4,8 @@ use crate::{
     option::CompressOptions,
     util::MoudleItemExt,
 };
-use rustc_hash::FxHashMap;
 use swc_atoms::js_word;
-use swc_common::util::take::Take;
+use swc_common::{collections::AHashMap, util::take::Take};
 use swc_ecma_ast::*;
 use swc_ecma_utils::{ident::IdentLike, Id};
 use swc_ecma_visit::{noop_visit_mut_type, VisitMut, VisitMutWith, VisitWith};
@@ -33,7 +32,7 @@ struct PrecompressOptimizer<'a> {
     marks: Marks,
 
     data: Option<ProgramData>,
-    fn_decl_count: FxHashMap<Id, usize>,
+    fn_decl_count: AHashMap<Id, usize>,
     ctx: Ctx,
 }
 
