@@ -30,7 +30,8 @@ pub(crate) fn incr_base54(init: &mut usize) -> String {
         base = 64;
     }
 
-    if ret.is_reserved() {
+    if ret.is_reserved() || ret.is_reserved_in_strict_bind() || ret.is_reserved_in_strict_mode(true)
+    {
         return incr_base54(init);
     }
 
